@@ -26,7 +26,6 @@ import (
 	"ariga.io/atlas/sql/sqlite"
 	_ "ariga.io/atlas/sql/sqlite"
 	_ "ariga.io/atlas/sql/sqlite/sqlitecheck"
-
 	"github.com/fatih/color"
 	_ "github.com/mattn/go-sqlite3"
 	"github.com/stretchr/testify/require"
@@ -106,6 +105,17 @@ func TestMigrate_Apply(t *testing.T) {
 	require.ErrorIs(t, err, errLock)
 	require.True(t, strings.HasPrefix(s, "Error: acquiring database lock: "+errLock.Error()))
 
+	// Apply zero throws error.
+	for _, n := range []string{"-1", "0"} {
+		_, err = runCmd(
+			Root, "migrate", "apply",
+			"--dir", "file://testdata/sqlite",
+			"--url", fmt.Sprintf("sqlite://file:%s?cache=shared&_fk=1", filepath.Join(p, "test.db")),
+			"--", n,
+		)
+		require.EqualError(t, err, fmt.Sprintf("cannot apply '%s' migration files", n))
+	}
+
 	// Will work and print stuff to the console.
 	s, err = runCmd(
 		Root, "migrate", "apply",
@@ -492,7 +502,7 @@ func TestMigrate_Lint(t *testing.T) {
 		"--latest", "1",
 	)
 	require.Error(t, err)
-	require.Equal(t, "2.sql: destructive change detected:\n\n\tL1: Dropping table \"t\"\n\n", s)
+	require.Equal(t, "2.sql: destructive changes detected:\n\n\tL1: Dropping table \"t\"\n\n", s)
 	s, err = runCmd(
 		Root, "migrate", "lint",
 		"--dir", "file://"+p,
