@@ -228,7 +228,9 @@ type parser struct{}
 
 // ParseURL implements the sqlclient.URLParser interface.
 func (parser) ParseURL(u *url.URL) *sqlclient.URL {
-	u.Query().Set("parseTime", "true")
+	v := u.Query()
+	v.Set("parseTime", "true")
+	u.RawQuery = v.Encode()
 	return &sqlclient.URL{URL: u, DSN: dsn(u), Schema: strings.TrimPrefix(u.Path, "/")}
 }
 
